@@ -834,11 +834,15 @@ openmpi()
         case ${ARCH} in
             ppc64)
                 kernel_minor=$(echo $K_VER | cut -d '-' -f 1 | cut -d '.' -f 4)
-                if [ "${DISTRIBUTION}" == "SuSE" ] && is_integer "$kernel_minor" && [ $kernel_minor -ge 46 ]; then
+                if [ "${DISTRIBUTION}" == "SuSE" ] && is_integer "$kernel_minor" && [ $kernel_minor -ge 46 ] && [ $kernel_minor -lt 53 ]; then
                     # SLES 10 SP1
                     USE_DEFAULT_RPM_OPT_FLAGS=0
                     OMPI_LDFLAGS='LDFLAGS=\"-L/usr/lib64 -Wl,-R'$STACK_PREFIX/$OMPI_LIBDIR' -Wl,-rpath-link,'$BUILD_ROOT/$STACK_PREFIX/$OMPI_LIBDIR'\"'
                     COMP_OPTIONS="$COMP_OPTIONS --with-wrapper-ldflags=\"$OMPI_RPATH -g -O2\""
+                elif [ "${DISTRIBUTION}" == "SuSE" ] && is_integer "$kernel_minor" && [ $kernel_minor -ge 53 ]; then
+                    OMPI_LDFLAGS='LDFLAGS=\"-L/usr/lib64 -L/usr/lib/gcc/powerpc64-suse-linux/4.1.2/64 -Wl,-R'$STACK_PREFIX/$OMPI_LIBDIR' -Wl,-rpath-link,'$BUILD_ROOT/$STACK_PREFIX/$OMPI_LIBDIR'\"'
+                    COMP_OPTIONS="$COMP_OPTIONS CFLAGS=\"-m64 -O2\" CXXFLAGS=\"-m64 -O2\" FCFLAGS=\"-m64 -O2\" FFLAGS=\"-m64 -O2\" --with-wrapper-ldflags=\"$OMPI_RPATH -g -O2 -m64 -L/usr/lib64\" --with-wrapper-cflags=-m64 --with-wrapper-cxxflags=-m64 --with-wrapper-fflags=-m64 --with-wrapper-fcflags=-m64"
+                    OMPI_WRAPPER_CXX_FLAGS="-m64 $OMPI_WRAPPER_CXX_FLAGS"
                 else
                     # In the ppc64 case, add -m64 to all the relevant
                     # flags because it's not the default.  Also
